==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualMachineScaleSetNetworkConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.DeleteOptions
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a virtual machine scale set network profile's network configurations.
 * @property deleteOption Specify what happens to the network interface when the VM is deleted
 * @property disableTcpStateTracking Specifies whether the network interface is disabled for tcp state tracking.
 * @property dnsSettings The dns settings to be applied on the network interfaces.
 * @property enableAcceleratedNetworking Specifies whether the network interface is accelerated networking-enabled.
 * @property enableFpga Specifies whether the network interface is FPGA networking-enabled.
 * @property enableIPForwarding Whether IP forwarding enabled on this NIC.
 * @property ipConfigurations Specifies the IP configurations of the network interface.
 * @property name The network configuration name.
 * @property networkSecurityGroup The network security group.
 * @property primary Specifies the primary network interface in case the virtual machine has more than 1 network interface.
 */
public data class VirtualMachineScaleSetNetworkConfigurationArgs(
    public val deleteOption: Output<Either<String, DeleteOptions>>? = null,
    public val disableTcpStateTracking: Output<Boolean>? = null,
    public val dnsSettings: Output<VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs>? = null,
    public val enableAcceleratedNetworking: Output<Boolean>? = null,
    public val enableFpga: Output<Boolean>? = null,
    public val enableIPForwarding: Output<Boolean>? = null,
    public val ipConfigurations: Output<List<VirtualMachineScaleSetIPConfigurationArgs>>,
    public val name: Output<String>,
    public val networkSecurityGroup: Output<SubResourceArgs>? = null,
    public val primary: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs =
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs.builder()
            .deleteOption(
                deleteOption?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .disableTcpStateTracking(disableTcpStateTracking?.applyValue({ args0 -> args0 }))
            .dnsSettings(dnsSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .enableAcceleratedNetworking(enableAcceleratedNetworking?.applyValue({ args0 -> args0 }))
            .enableFpga(enableFpga?.applyValue({ args0 -> args0 }))
            .enableIPForwarding(enableIPForwarding?.applyValue({ args0 -> args0 }))
            .ipConfigurations(
                ipConfigurations.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .name(name.applyValue({ args0 -> args0 }))
            .networkSecurityGroup(
                networkSecurityGroup?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .primary(primary?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineScaleSetNetworkConfigurationArgs].
 */
@PulumiTagMarker
public class VirtualMachineScaleSetNetworkConfigurationArgsBuilder internal constructor() {
    private var deleteOption: Output<Either<String, DeleteOptions>>? = null

    private var disableTcpStateTracking: Output<Boolean>? = null

    private var dnsSettings: Output<VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs>? = null

    private var enableAcceleratedNetworking: Output<Boolean>? = null

    private var enableFpga: Output<Boolean>? = null

    private var enableIPForwarding: Output<Boolean>? = null

    private var ipConfigurations: Output<List<VirtualMachineScaleSetIPConfigurationArgs>>? = null

    private var name: Output<String>? = null

    private var networkSecurityGroup: Output<SubResourceArgs>? = null

    private var primary: Output<Boolean>? = null

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("ywjyiggkmnohvdjc")
    public suspend fun deleteOption(`value`: Output<Either<String, DeleteOptions>>) {
        this.deleteOption = value
    }

    /**
     * @param value Specifies whether the network interface is disabled for tcp state tracking.
     */
    @JvmName("iunsmgmcgdmmailm")
    public suspend fun disableTcpStateTracking(`value`: Output<Boolean>) {
        this.disableTcpStateTracking = value
    }

    /**
     * @param value The dns settings to be applied on the network interfaces.
     */
    @JvmName("vqdcepecpwirvoit")
    public suspend
    fun dnsSettings(`value`: Output<VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs>) {
        this.dnsSettings = value
    }

    /**
     * @param value Specifies whether the network interface is accelerated networking-enabled.
     */
    @JvmName("xsexyxylsmipvdhi")
    public suspend fun enableAcceleratedNetworking(`value`: Output<Boolean>) {
        this.enableAcceleratedNetworking = value
    }

    /**
     * @param value Specifies whether the network interface is FPGA networking-enabled.
     */
    @JvmName("ckuoealamhoumnbf")
    public suspend fun enableFpga(`value`: Output<Boolean>) {
        this.enableFpga = value
    }

    /**
     * @param value Whether IP forwarding enabled on this NIC.
     */
    @JvmName("ayshnhdicjxtcndj")
    public suspend fun enableIPForwarding(`value`: Output<Boolean>) {
        this.enableIPForwarding = value
    }

    /**
     * @param value Specifies the IP configurations of the network interface.
     */
    @JvmName("rcfxbupfrqknwepe")
    public suspend
    fun ipConfigurations(`value`: Output<List<VirtualMachineScaleSetIPConfigurationArgs>>) {
        this.ipConfigurations = value
    }

    @JvmName("xcfsakxnkjcstvca")
    public suspend fun ipConfigurations(
        vararg
        values: Output<VirtualMachineScaleSetIPConfigurationArgs>,
    ) {
        this.ipConfigurations = Output.all(values.asList())
    }

    /**
     * @param values Specifies the IP configurations of the network interface.
     */
    @JvmName("blmryulhpgmhylyc")
    public suspend
    fun ipConfigurations(values: List<Output<VirtualMachineScaleSetIPConfigurationArgs>>) {
        this.ipConfigurations = Output.all(values)
    }

    /**
     * @param value The network configuration name.
     */
    @JvmName("vatrwspyxxolvset")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The network security group.
     */
    @JvmName("uifcoxlhbfsvnsyh")
    public suspend fun networkSecurityGroup(`value`: Output<SubResourceArgs>) {
        this.networkSecurityGroup = value
    }

    /**
     * @param value Specifies the primary network interface in case the virtual machine has more than 1 network interface.
     */
    @JvmName("kkaffejqcshmvldu")
    public suspend fun primary(`value`: Output<Boolean>) {
        this.primary = value
    }

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("ifwphcybbfbjvrub")
    public suspend fun deleteOption(`value`: Either<String, DeleteOptions>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deleteOption = mapped
    }

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("akfunrxuympfusfm")
    public fun deleteOption(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeleteOptions>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOption = mapped
    }

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("idllvpbbyjrliqpl")
    public fun deleteOption(`value`: DeleteOptions) {
        val toBeMapped = Either.ofRight<String, DeleteOptions>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOption = mapped
    }

    /**
     * @param value Specifies whether the network interface is disabled for tcp state tracking.
     */
    @JvmName("uhhgpgevtvbibkku")
    public suspend fun disableTcpStateTracking(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disableTcpStateTracking = mapped
    }

    /**
     * @param value The dns settings to be applied on the network interfaces.
     */
    @JvmName("wyawbbkyhiwtjbye")
    public suspend
    fun dnsSettings(`value`: VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsSettings = mapped
    }

    /**
     * @param argument The dns settings to be applied on the network interfaces.
     */
    @JvmName("wyrdanmkjbkecwob")
    public suspend
    fun dnsSettings(argument: suspend VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgsBuilder.() -> Unit) {
        val toBeMapped =
            VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.dnsSettings = mapped
    }

    /**
     * @param value Specifies whether the network interface is accelerated networking-enabled.
     */
    @JvmName("jwwldmawuwftiqms")
    public suspend fun enableAcceleratedNetworking(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableAcceleratedNetworking = mapped
    }

    /**
     * @param value Specifies whether the network interface is FPGA networking-enabled.
     */
    @JvmName("xevjlfbjumhycgie")
    public suspend fun enableFpga(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableFpga = mapped
    }

    /**
     * @param value Whether IP forwarding enabled on this NIC.
     */
    @JvmName("fvqnhickonpqvwxc")
    public suspend fun enableIPForwarding(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableIPForwarding = mapped
    }

    /**
     * @param value Specifies the IP configurations of the network interface.
     */
    @JvmName("rsxygylcbfqwvxpv")
    public suspend fun ipConfigurations(`value`: List<VirtualMachineScaleSetIPConfigurationArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipConfigurations = mapped
    }

    /**
     * @param argument Specifies the IP configurations of the network interface.
     */
    @JvmName("ywfagdcfgececdnj")
    public suspend
    fun ipConfigurations(argument: List<suspend VirtualMachineScaleSetIPConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualMachineScaleSetIPConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.ipConfigurations = mapped
    }

    /**
     * @param argument Specifies the IP configurations of the network interface.
     */
    @JvmName("mjhpcoauddahbahu")
    public suspend fun ipConfigurations(
        vararg
        argument: suspend VirtualMachineScaleSetIPConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualMachineScaleSetIPConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.ipConfigurations = mapped
    }

    /**
     * @param argument Specifies the IP configurations of the network interface.
     */
    @JvmName("xlrkqhoxlnjspnvq")
    public suspend
    fun ipConfigurations(argument: suspend VirtualMachineScaleSetIPConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualMachineScaleSetIPConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.ipConfigurations = mapped
    }

    /**
     * @param values Specifies the IP configurations of the network interface.
     */
    @JvmName("ijfcblbknebfknpq")
    public suspend fun ipConfigurations(vararg values: VirtualMachineScaleSetIPConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipConfigurations = mapped
    }

    /**
     * @param value The network configuration name.
     */
    @JvmName("gxswjbqefxoahnoo")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The network security group.
     */
    @JvmName("eklwuhvmjtlxsplk")
    public suspend fun networkSecurityGroup(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkSecurityGroup = mapped
    }

    /**
     * @param argument The network security group.
     */
    @JvmName("kakhfvopnbeugdfl")
    public suspend fun networkSecurityGroup(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.networkSecurityGroup = mapped
    }

    /**
     * @param value Specifies the primary network interface in case the virtual machine has more than 1 network interface.
     */
    @JvmName("kiqltvqaryffeqqw")
    public suspend fun primary(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primary = mapped
    }

    internal fun build(): VirtualMachineScaleSetNetworkConfigurationArgs =
        VirtualMachineScaleSetNetworkConfigurationArgs(
            deleteOption = deleteOption,
            disableTcpStateTracking = disableTcpStateTracking,
            dnsSettings = dnsSettings,
            enableAcceleratedNetworking = enableAcceleratedNetworking,
            enableFpga = enableFpga,
            enableIPForwarding = enableIPForwarding,
            ipConfigurations = ipConfigurations ?: throw PulumiNullFieldException("ipConfigurations"),
            name = name ?: throw PulumiNullFieldException("name"),
            networkSecurityGroup = networkSecurityGroup,
            primary = primary,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualMachineScaleSetNetworkConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.DeleteOptions
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a virtual machine scale set network profile's network configurations.
 * @property deleteOption Specify what happens to the network interface when the VM is deleted
 * @property disableTcpStateTracking Specifies whether the network interface is disabled for tcp state tracking.
 * @property dnsSettings The dns settings to be applied on the network interfaces.
 * @property enableAcceleratedNetworking Specifies whether the network interface is accelerated networking-enabled.
 * @property enableFpga Specifies whether the network interface is FPGA networking-enabled.
 * @property enableIPForwarding Whether IP forwarding enabled on this NIC.
 * @property ipConfigurations Specifies the IP configurations of the network interface.
 * @property name The network configuration name.
 * @property networkSecurityGroup The network security group.
 * @property primary Specifies the primary network interface in case the virtual machine has more than 1 network interface.
 */
public data class VirtualMachineScaleSetNetworkConfigurationArgs(
    public val deleteOption: Output<Either<String, DeleteOptions>>? = null,
    public val disableTcpStateTracking: Output<Boolean>? = null,
    public val dnsSettings: Output<VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs>? = null,
    public val enableAcceleratedNetworking: Output<Boolean>? = null,
    public val enableFpga: Output<Boolean>? = null,
    public val enableIPForwarding: Output<Boolean>? = null,
    public val ipConfigurations: Output<List<VirtualMachineScaleSetIPConfigurationArgs>>,
    public val name: Output<String>,
    public val networkSecurityGroup: Output<SubResourceArgs>? = null,
    public val primary: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs =
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs.builder()
            .deleteOption(
                deleteOption?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .disableTcpStateTracking(disableTcpStateTracking?.applyValue({ args0 -> args0 }))
            .dnsSettings(dnsSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .enableAcceleratedNetworking(enableAcceleratedNetworking?.applyValue({ args0 -> args0 }))
            .enableFpga(enableFpga?.applyValue({ args0 -> args0 }))
            .enableIPForwarding(enableIPForwarding?.applyValue({ args0 -> args0 }))
            .ipConfigurations(
                ipConfigurations.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .name(name.applyValue({ args0 -> args0 }))
            .networkSecurityGroup(
                networkSecurityGroup?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .primary(primary?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineScaleSetNetworkConfigurationArgs].
 */
@PulumiTagMarker
public class VirtualMachineScaleSetNetworkConfigurationArgsBuilder internal constructor() {
    private var deleteOption: Output<Either<String, DeleteOptions>>? = null

    private var disableTcpStateTracking: Output<Boolean>? = null

    private var dnsSettings: Output<VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs>? = null

    private var enableAcceleratedNetworking: Output<Boolean>? = null

    private var enableFpga: Output<Boolean>? = null

    private var enableIPForwarding: Output<Boolean>? = null

    private var ipConfigurations: Output<List<VirtualMachineScaleSetIPConfigurationArgs>>? = null

    private var name: Output<String>? = null

    private var networkSecurityGroup: Output<SubResourceArgs>? = null

    private var primary: Output<Boolean>? = null

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("sjnbhutypqbrybea")
    public suspend fun deleteOption(`value`: Output<Either<String, DeleteOptions>>) {
        this.deleteOption = value
    }

    /**
     * @param value Specifies whether the network interface is disabled for tcp state tracking.
     */
    @JvmName("ojaeskgqkibdocjr")
    public suspend fun disableTcpStateTracking(`value`: Output<Boolean>) {
        this.disableTcpStateTracking = value
    }

    /**
     * @param value The dns settings to be applied on the network interfaces.
     */
    @JvmName("qphfiikqlgllfyak")
    public suspend
    fun dnsSettings(`value`: Output<VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs>) {
        this.dnsSettings = value
    }

    /**
     * @param value Specifies whether the network interface is accelerated networking-enabled.
     */
    @JvmName("feermegjdavifwfq")
    public suspend fun enableAcceleratedNetworking(`value`: Output<Boolean>) {
        this.enableAcceleratedNetworking = value
    }

    /**
     * @param value Specifies whether the network interface is FPGA networking-enabled.
     */
    @JvmName("atkywggmbjaxyixx")
    public suspend fun enableFpga(`value`: Output<Boolean>) {
        this.enableFpga = value
    }

    /**
     * @param value Whether IP forwarding enabled on this NIC.
     */
    @JvmName("agktnguikxfchoqp")
    public suspend fun enableIPForwarding(`value`: Output<Boolean>) {
        this.enableIPForwarding = value
    }

    /**
     * @param value Specifies the IP configurations of the network interface.
     */
    @JvmName("lcwclwwvxguwnmjg")
    public suspend
    fun ipConfigurations(`value`: Output<List<VirtualMachineScaleSetIPConfigurationArgs>>) {
        this.ipConfigurations = value
    }

    @JvmName("vssknxgwuytiqgty")
    public suspend fun ipConfigurations(
        vararg
        values: Output<VirtualMachineScaleSetIPConfigurationArgs>,
    ) {
        this.ipConfigurations = Output.all(values.asList())
    }

    /**
     * @param values Specifies the IP configurations of the network interface.
     */
    @JvmName("tdpgnhxkpehlsikn")
    public suspend
    fun ipConfigurations(values: List<Output<VirtualMachineScaleSetIPConfigurationArgs>>) {
        this.ipConfigurations = Output.all(values)
    }

    /**
     * @param value The network configuration name.
     */
    @JvmName("mxagsltakoyejlrn")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The network security group.
     */
    @JvmName("oofsktgcxvchlghx")
    public suspend fun networkSecurityGroup(`value`: Output<SubResourceArgs>) {
        this.networkSecurityGroup = value
    }

    /**
     * @param value Specifies the primary network interface in case the virtual machine has more than 1 network interface.
     */
    @JvmName("kmhxrdqayqkdvgew")
    public suspend fun primary(`value`: Output<Boolean>) {
        this.primary = value
    }

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("lcdhurfcnibxkkit")
    public suspend fun deleteOption(`value`: Either<String, DeleteOptions>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deleteOption = mapped
    }

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("krgnaqtfctqgiqdi")
    public fun deleteOption(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeleteOptions>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOption = mapped
    }

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("gkygouyxivcvpycp")
    public fun deleteOption(`value`: DeleteOptions) {
        val toBeMapped = Either.ofRight<String, DeleteOptions>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOption = mapped
    }

    /**
     * @param value Specifies whether the network interface is disabled for tcp state tracking.
     */
    @JvmName("nfcwhgojqvueqtsr")
    public suspend fun disableTcpStateTracking(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disableTcpStateTracking = mapped
    }

    /**
     * @param value The dns settings to be applied on the network interfaces.
     */
    @JvmName("fkfhhlagnsfqrubv")
    public suspend
    fun dnsSettings(`value`: VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsSettings = mapped
    }

    /**
     * @param argument The dns settings to be applied on the network interfaces.
     */
    @JvmName("auewcrqytnimlddm")
    public suspend
    fun dnsSettings(argument: suspend VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgsBuilder.() -> Unit) {
        val toBeMapped =
            VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.dnsSettings = mapped
    }

    /**
     * @param value Specifies whether the network interface is accelerated networking-enabled.
     */
    @JvmName("ynqjkksabrapcise")
    public suspend fun enableAcceleratedNetworking(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableAcceleratedNetworking = mapped
    }

    /**
     * @param value Specifies whether the network interface is FPGA networking-enabled.
     */
    @JvmName("gooqafmwbdnsxyyj")
    public suspend fun enableFpga(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableFpga = mapped
    }

    /**
     * @param value Whether IP forwarding enabled on this NIC.
     */
    @JvmName("jkvsskpkbmkprssr")
    public suspend fun enableIPForwarding(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableIPForwarding = mapped
    }

    /**
     * @param value Specifies the IP configurations of the network interface.
     */
    @JvmName("jledewuyesxxhvkg")
    public suspend fun ipConfigurations(`value`: List<VirtualMachineScaleSetIPConfigurationArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipConfigurations = mapped
    }

    /**
     * @param argument Specifies the IP configurations of the network interface.
     */
    @JvmName("fjgtburtdpjusciw")
    public suspend
    fun ipConfigurations(argument: List<suspend VirtualMachineScaleSetIPConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualMachineScaleSetIPConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.ipConfigurations = mapped
    }

    /**
     * @param argument Specifies the IP configurations of the network interface.
     */
    @JvmName("kbipuboucyujcrqj")
    public suspend fun ipConfigurations(
        vararg
        argument: suspend VirtualMachineScaleSetIPConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualMachineScaleSetIPConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.ipConfigurations = mapped
    }

    /**
     * @param argument Specifies the IP configurations of the network interface.
     */
    @JvmName("dtjahhfdedidicfi")
    public suspend
    fun ipConfigurations(argument: suspend VirtualMachineScaleSetIPConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualMachineScaleSetIPConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.ipConfigurations = mapped
    }

    /**
     * @param values Specifies the IP configurations of the network interface.
     */
    @JvmName("rewfkjvbnuyhwxul")
    public suspend fun ipConfigurations(vararg values: VirtualMachineScaleSetIPConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipConfigurations = mapped
    }

    /**
     * @param value The network configuration name.
     */
    @JvmName("vgvoaxuogrnjbgiu")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The network security group.
     */
    @JvmName("pgdpihxhcwwthmhn")
    public suspend fun networkSecurityGroup(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkSecurityGroup = mapped
    }

    /**
     * @param argument The network security group.
     */
    @JvmName("cmnlgvhirkqydgch")
    public suspend fun networkSecurityGroup(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.networkSecurityGroup = mapped
    }

    /**
     * @param value Specifies the primary network interface in case the virtual machine has more than 1 network interface.
     */
    @JvmName("vlvueyflxltvrcrf")
    public suspend fun primary(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primary = mapped
    }

    internal fun build(): VirtualMachineScaleSetNetworkConfigurationArgs =
        VirtualMachineScaleSetNetworkConfigurationArgs(
            deleteOption = deleteOption,
            disableTcpStateTracking = disableTcpStateTracking,
            dnsSettings = dnsSettings,
            enableAcceleratedNetworking = enableAcceleratedNetworking,
            enableFpga = enableFpga,
            enableIPForwarding = enableIPForwarding,
            ipConfigurations = ipConfigurations ?: throw PulumiNullFieldException("ipConfigurations"),
            name = name ?: throw PulumiNullFieldException("name"),
            networkSecurityGroup = networkSecurityGroup,
            primary = primary,
        )
}
